require 'studio_game/spec_helper'
require 'studio_game/game'

module StudioGame
  describe Game do
    before do
      $stdout = StringIO.new
      @game = Game.new("Knuckleheads")
      @initial_health = 100
      @player = Player.new("moe", @initial_health)
      @game.add_player(@player)

    end

    context "When a high number is rolled" do
      it "adds 15 to the players health" do
        LoadedDie.any_instance.stub(:roll).and_return(5)
        @game.play(2)
        @player.health.should == @initial_health + (15 * 2)
      end
    end

    context "When a medium number is rolled" do
      it "does not change the players health" do
        LoadedDie.any_instance.stub(:roll).and_return(3)
        @game.play(2)
        @player.health.should == @initial_health
      end
    end

    context "When a low number is rolled" do
      it "subtracts 15 from the players health" do
        LoadedDie.any_instance.stub(:roll).and_return(1)
        @game.play(2)
        @player.health.should == @initial_health - (10 * 2)
      end
    end

    it "assigns a treasure for points during a player's turn" do
      game = Game.new("Knuckleheads")
      player = Player.new("moe")

      game.add_player(player)

      game.play(1)

      player.points.should_not be_zero

      # or use alternate expectation syntax:
      # expect(player.points).not_to be_zero
    end

    it "computes total points as the sum of all player points" do
    game = Game.new("Knuckleheads")

    player1 = Player.new("jack")
    player2 = Player.new("jill")

    game.add_player(player1)
    game.add_player(player2)

    player1.found_treasure(Treasure.new(:hammer, 50))
    player1.found_treasure(Treasure.new(:hammer, 50))
    player2.found_treasure(Treasure.new(:crowbar, 400))

    game.total_points.should == 500
    end
  end
end
