require 'studio_game/spec_helper'
require 'studio_game/player'
require 'studio_game/treasure_trove'

module StudioGame
  describe Player do
    before do
      $stdout = StringIO.new
      @initial_health = 150
      @p = Player.new("larry", @initial_health)
    end

    it "has a capitalized title" do
      @p.name.should == "Larry"
    end

    it "has an initial health" do
      @p.health.should == 150
    end

    it "has a string representation" do
      @p.found_treasure(Treasure.new(:hammer, 50))
      @p.found_treasure(Treasure.new(:hammer, 50))

      @p.to_s.should == "I'm Larry with a health = 150, points = 100, and score = 250"
    end

    it "computes a score as the sum of its health and points" do
      @p.found_treasure(Treasure.new(:hammer, 50))
      @p.found_treasure(Treasure.new(:hammer, 50))
      @p.score.should == 250
    end

    it "increases health by 15 when w00ted" do
      @p.w00t
      @p.health.should == @initial_health + 15
    end

    it "decreases health by 10 when blammed" do
      @p.blam
      @p.health.should == @initial_health - 10
    end

    it "computes points as the sum of all treasure points" do
    @p.points.should == 0

    @p.found_treasure(Treasure.new(:hammer, 50))

    @p.points.should == 50

    @p.found_treasure(Treasure.new(:crowbar, 400))

    @p.points.should == 450

    @p.found_treasure(Treasure.new(:hammer, 50))

    @p.points.should == 500
  end

    context "With a health greater than 100" do
      before do
        @initial_health = 150
        @p = Player.new("jimmy", @initial_health)
      end

      it "is strong" do
        @p.should be_strong
      end
    end

    context "With a health of 100 or less" do
      before do
        @initial_health = 100
        @p = Player.new("jimmy", @initial_health)
      end

      it "is wimpy" do
        @p.should_not be_strong
      end
    end

    it "yields each found treasure and its total points" do
    @p.found_treasure(Treasure.new(:skillet, 100))
    @p.found_treasure(Treasure.new(:skillet, 100))
    @p.found_treasure(Treasure.new(:hammer, 50))
    @p.found_treasure(Treasure.new(:bottle, 5))
    @p.found_treasure(Treasure.new(:bottle, 5))
    @p.found_treasure(Treasure.new(:bottle, 5))
    @p.found_treasure(Treasure.new(:bottle, 5))
    @p.found_treasure(Treasure.new(:bottle, 5))

    yielded = []
    @p.each_found_treasure do |treasure|
      yielded << treasure
    end

    yielded.should == [
      Treasure.new(:skillet, 200),
      Treasure.new(:hammer, 50),
      Treasure.new(:bottle, 25)
   ]
  end

  it "can create a player from a csv string" do
    player = Player.from_csv("tim,100")
    player.name.should == "Tim"
    player.health.should == 100
  end

  end
end
